/* eslint-env mocha */
'use strict';

const assert = require('assert');
const common = require('../../lib/common');

describe('Common', function () {

  describe('fileScope', function () {
    it('names a file path', function () {
      const filename = 'lib/foo/bar.js';
      const result = common.fileScope(filename)('baz');
      assert.strictEqual(result, 'bar:baz');
    });
    it('names an index path', function () {
      const filename = 'lib/foo/index.js';
      const result = common.fileScope(filename)('baz');
      assert.strictEqual(result, 'foo:baz');
    });
  }); // fileScope

  describe('ensureArray', function () {
    it('returns empty array for no data', function () {
      const result = common.ensureArray();
      assert.deepStrictEqual(result, []);
    });
    it('returns same array passed in', function () {
      const expected = [1, 2, 3, 'foo'];
      const result = common.ensureArray(expected);
      assert.deepStrictEqual(result, expected);
    });
    it('returns array containing non-array data', function () {
      const data = 'bar';
      const result = common.ensureArray(data);
      assert.deepStrictEqual(result, [data]);
    });
  }); // ensureArray

}); // Common
